==> rest-assured-2.3.3-sources.jar: com/jayway/restassured/internal/RequestLogSpecificationImpl.java <==
package com.jayway.restassured.internal;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class RequestLogSpecificationImpl
  extends com.jayway.restassured.internal.LogSpecificationImpl  implements
    com.jayway.restassured.specification.RequestLogSpecification {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  com.jayway.restassured.specification.RequestSpecification getRequestSpecification() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  void setRequestSpecification(com.jayway.restassured.specification.RequestSpecification value) { }
public  com.jayway.restassured.internal.log.LogRepository getLogRepository() { return (com.jayway.restassured.internal.log.LogRepository)null;}
public  void setLogRepository(com.jayway.restassured.internal.log.LogRepository value) { }
public  com.jayway.restassured.specification.RequestSpecification params() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification parameters() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification body() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification body(boolean shouldPrettyPrint) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification all(boolean shouldPrettyPrint) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification everything(boolean shouldPrettyPrint) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification all() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification everything() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification headers() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification cookies() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification ifValidationFails() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification ifValidationFails(com.jayway.restassured.filter.log.LogDetail logDetail) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification ifValidationFails(com.jayway.restassured.filter.log.LogDetail logDetail, boolean shouldPrettyPrint) { return (com.jayway.restassured.specification.RequestSpecification)null;}
}

==> rest-assured-2.6.0-sources.jar: com/jayway/restassured/internal/RequestLogSpecificationImpl.java <==
package com.jayway.restassured.internal;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class RequestLogSpecificationImpl
  extends com.jayway.restassured.internal.LogSpecificationImpl  implements
    com.jayway.restassured.specification.RequestLogSpecification {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  com.jayway.restassured.specification.RequestSpecification getRequestSpecification() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  void setRequestSpecification(com.jayway.restassured.specification.RequestSpecification value) { }
public  com.jayway.restassured.internal.log.LogRepository getLogRepository() { return (com.jayway.restassured.internal.log.LogRepository)null;}
public  void setLogRepository(com.jayway.restassured.internal.log.LogRepository value) { }
public  com.jayway.restassured.specification.RequestSpecification params() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification parameters() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification path() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification method() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification body() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification body(boolean shouldPrettyPrint) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification all(boolean shouldPrettyPrint) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification everything(boolean shouldPrettyPrint) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification all() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification everything() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification headers() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification cookies() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification ifValidationFails() { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification ifValidationFails(com.jayway.restassured.filter.log.LogDetail logDetail) { return (com.jayway.restassured.specification.RequestSpecification)null;}
public  com.jayway.restassured.specification.RequestSpecification ifValidationFails(com.jayway.restassured.filter.log.LogDetail logDetail, boolean shouldPrettyPrint) { return (com.jayway.restassured.specification.RequestSpecification)null;}
}
